@@ -1,12 +1,15 @@
-package Test::BDD::Cucumber::Harness::Data;
-$Test::BDD::Cucumber::Harness::Data::VERSION = '0.84';
+use v5.14;
+use warnings;
+
+package Test::BDD::Cucumber::Harness::Data 0.86;
+
 =head1 NAME
 
 Test::BDD::Cucumber::Harness::Data - Builds up an internal data representation of test passes / failures
 
 =head1 VERSION
 
-version 0.84
+version 0.86
 
 =head1 DESCRIPTION
 
@@ -14,8 +17,6 @@ A L<Test::BDD::Cucumber::Harness> subclass which collates test data
 
 =cut
 
-use strict;
-use warnings;
 use Moo;
 use Types::Standard qw( HashRef ArrayRef );
 use Test::More;
