@@ -1,12 +1,15 @@
-package Test::BDD::Cucumber::Harness::JSON;
-$Test::BDD::Cucumber::Harness::JSON::VERSION = '0.83';
+use v5.14;
+use warnings;
+
+package Test::BDD::Cucumber::Harness::JSON 0.86;
+
 =head1 NAME
 
 Test::BDD::Cucumber::Harness::JSON - Generate results to JSON file
 
 =head1 VERSION
 
-version 0.83
+version 0.86
 
 =head1 DESCRIPTION
 
@@ -95,7 +98,7 @@ sub shutdown {
 
 sub format_tags {
     my ( $self, $tags_ref ) = @_;
-    return [ map { { name => '@' . $_ } } @$tags_ref ];
+    return [ map { { name => $_ } } @$tags_ref ];
 }
 
 sub format_description {
