@@ -1,12 +1,15 @@
-package Test::BDD::Cucumber::Harness::TestBuilder;
-$Test::BDD::Cucumber::Harness::TestBuilder::VERSION = '0.83';
+use v5.14;
+use warnings;
+
+package Test::BDD::Cucumber::Harness::TestBuilder 0.86;
+
 =head1 NAME
 
 Test::BDD::Cucumber::Harness::TestBuilder - Temporary redirector to TAP harness
 
 =head1 VERSION
 
-version 0.83
+version 0.86
 
 =head1 DESCRIPTION
 
