@@ -1,5 +1,8 @@
-package Test::BDD::Cucumber::I18n;
-$Test::BDD::Cucumber::I18n::VERSION = '0.83';
+use v5.14;
+use warnings;
+
+package Test::BDD::Cucumber::I18n 0.86;
+
 =encoding utf8
 
 =head1 NAME
@@ -8,7 +11,7 @@ Test::BDD::Cucumber::I18N - Internationalization
 
 =head1 VERSION
 
-version 0.83
+version 0.86
 
 =head1 DESCRIPTION
 
@@ -33,8 +36,6 @@ Internationalization of feature files and step definitions.
 
 =cut
 
-use strict;
-use warnings;
 use utf8;
 
 use base 'Exporter';
@@ -125,7 +126,7 @@ Gregor Goldbach C<glauschwuffel@nomaden.org>
 
 =head1 LICENSE
 
-  Copyright 2019-2021, Erik Huelsmann
+  Copyright 2019-2023, Erik Huelsmann
   Copyright 2014-2019, Gregor Goldbach; Licensed under the same terms as Perl
 
 =cut
