@@ -1,12 +1,15 @@
-package Test::BDD::Cucumber::Loader;
-$Test::BDD::Cucumber::Loader::VERSION = '0.83';
+use v5.14;
+use warnings;
+
+package Test::BDD::Cucumber::Loader 0.86;
+
 =head1 NAME
 
 Test::BDD::Cucumber::Loader - Simplify loading of Step Definition and feature files
 
 =head1 VERSION
 
-version 0.83
+version 0.86
 
 =head1 DESCRIPTION
 
@@ -28,8 +31,6 @@ the feature directory for C<*_steps.pl> files.
 
 =cut
 
-use strict;
-use warnings;
 
 use Path::Class;
 use File::Find::Rule;
@@ -88,7 +89,7 @@ Peter Sergeant C<pete@clueball.com>
 
 =head1 LICENSE
 
-  Copyright 2019-2021, Erik Huelsmann
+  Copyright 2019-2023, Erik Huelsmann
   Copyright 2011-2019, Peter Sergeant; Licensed under the same terms as Perl
 
 =cut
