@@ -1,5 +1,8 @@
-package Test::BDD::Cucumber::Model::Dataset;
-$Test::BDD::Cucumber::Model::Dataset::VERSION = '0.84';
+use v5.14;
+use warnings;
+
+package Test::BDD::Cucumber::Model::Dataset 0.86;
+
 use Moo;
 use Types::Standard qw( Str ArrayRef HashRef Bool InstanceOf );
 
@@ -9,7 +12,7 @@ Test::BDD::Cucumber::Model::Scenario - Model to represent a scenario
 
 =head1 VERSION
 
-version 0.84
+version 0.86
 
 =head1 DESCRIPTION
 
