@@ -1,5 +1,8 @@
-package Test::BDD::Cucumber::Model::Scenario;
-$Test::BDD::Cucumber::Model::Scenario::VERSION = '0.83';
+use v5.14;
+use warnings;
+
+package Test::BDD::Cucumber::Model::Scenario 0.86;
+
 use Moo;
 use Types::Standard qw( Str ArrayRef HashRef Bool InstanceOf );
 
@@ -11,7 +14,7 @@ Test::BDD::Cucumber::Model::Scenario - Model to represent a scenario
 
 =head1 VERSION
 
-version 0.83
+version 0.86
 
 =head1 DESCRIPTION
 
@@ -51,37 +54,6 @@ has 'steps' => (
     default => sub { [] }
 );
 
-=head2 data [deprecated]
-
-In case the scenario has associated datasets, returns the first one,
-unless it has tags associated (which wasn't supported until v0.63 of
-this module), in which case this method will die with an incompatibility
-error.
-
-This (since v0.65 read-only) accessor will be removed upon release of v1.0.
-
-=cut
-
-my $data_warn_count = 0;
-
-sub data {
-    # "pseudo" accessor
-    my $self = shift;
-    warn 'Scenario "data" accessor is deprecated since 0.65'
-        unless $data_warn_count++; # warn once
-    croak 'Scenario "data" accessor is read-only since 0.65' if @_;
-
-    return [] unless @{$self->datasets};
-
-    croak q{Scenario "data" accessor incompatible with multiple Examples}
-        if @{$self->datasets} > 1;
-    # Datasets without tags re-use the tags of the scenario
-    croak q{Scenario "data" accessor incompatible with Examples tags}
-        if $self->datasets->[0]->tags != $self->tags;
-
-    return $self->datasets->[0]->data;
-}
-
 =head2 datasets
 
 The dataset(s) associated with a scenario.
@@ -140,7 +112,7 @@ Peter Sergeant C<pete@clueball.com>
 
 =head1 LICENSE
 
-  Copyright 2019-2021, Erik Huelsmann
+  Copyright 2019-2023, Erik Huelsmann
   Copyright 2011-2019, Peter Sergeant; Licensed under the same terms as Perl
 
 =cut
