@@ -1,21 +1,22 @@
-package Test::BDD::Cucumber::StepFile;
-$Test::BDD::Cucumber::StepFile::VERSION = '0.83';
+use v5.14;
+use warnings;
+
+package Test::BDD::Cucumber::StepFile 0.86;
+
 =head1 NAME
 
 Test::BDD::Cucumber::StepFile - Functions for creating and loading Step Definitions
 
 =head1 VERSION
 
-version 0.83
+version 0.86
 
 =cut
 
-use strict;
-use warnings;
 use utf8;
 
 use Carp qw/croak/;
-use File::Spec qw/rel2abs/;
+use File::Spec;
 use Scalar::Util qw/reftype/;
 
 use Test::BDD::Cucumber::I18n qw(languages langdef keyword_to_subname);
@@ -192,7 +193,7 @@ Peter Sergeant C<pete@clueball.com>
 
 =head1 LICENSE
 
-  Copyright 2019-2021, Erik Huelsmann
+  Copyright 2019-2023, Erik Huelsmann
   Copyright 2011-2019, Peter Sergeant; Licensed under the same terms as Perl
 
 =cut
